==> wala_1.3.9.orig.tar.xz: WALA-R_1.3.9/com.ibm.wala.dalvik/src/com/ibm/wala/dalvik/dex/instructions/Constant.java <==
/*
 * This program and the accompanying materials
 * are made available under the terms of the Eclipse Public License v1.0
 * which accompanies this distribution, and is available at
 * http://www.eclipse.org/legal/epl-v10.html.
 * 
 * This file is a derivative of code released under the terms listed below.  
 *
 */
/*
 *
 * Copyright (c) 2009-2012,
 *
 *  Adam Fuchs          <afuchs@cs.umd.edu>
 *  Avik Chaudhuri      <avik@cs.umd.edu>
 *  Steve Suh           <suhsteve@gmail.com>
 *
 * All rights reserved.
 *
 * Redistribution and use in source and binary forms, with or without
 * modification, are permitted provided that the following conditions are met:
 *
 * 1. Redistributions of source code must retain the above copyright notice,
 * this list of conditions and the following disclaimer.
 *
 * 2. Redistributions in binary form must reproduce the above copyright notice,
 * this list of conditions and the following disclaimer in the documentation
 * and/or other materials provided with the distribution.
 *
 * 3. The names of the contributors may not be used to endorse or promote
 * products derived from this software without specific prior written
 * permission.
 *
 * THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS "AS IS"
 * AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE
 * IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE
 * ARE DISCLAIMED. IN NO EVENT SHALL THE COPYRIGHT OWNER OR CONTRIBUTORS BE
 * LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY, OR
 * CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF
 * SUBSTITUTE GOODS OR SERVICES; LOSS OF USE, DATA, OR PROFITS; OR BUSINESS
 * INTERRUPTION) HOWEVER CAUSED AND ON ANY THEORY OF LIABILITY, WHETHER IN
 * CONTRACT, STRICT LIABILITY, OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE)
 * ARISING IN ANY WAY OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE
 * POSSIBILITY OF SUCH DAMAGE.
 *
 *
 */

package com.ibm.wala.dalvik.dex.instructions;

import org.jf.dexlib.Code.Opcode;

import com.ibm.wala.dalvik.classLoader.DexIMethod;
import com.ibm.wala.types.TypeReference;

public abstract class Constant extends Instruction {

    public final int destination;

    public static class LongConstant extends Constant {
        public final long value;
        public LongConstant(int pc, long value, int destination, Opcode opcode, DexIMethod method)
        {
            super(pc, destination, opcode, method);
            this.value = value;
        }

    }

    protected Constant(int pc, int destination, Opcode opcode, DexIMethod method) {
        super(pc, opcode, method);
        this.destination = destination;
    }

    public static class IntConstant extends Constant
    {
        public final int value;
        public IntConstant(int pc, int value, int destination, Opcode opcode, DexIMethod method)
        {
            super(pc, destination, opcode, method);
            this.value = value;
        }
    }

    public static class StringConstant extends Constant
    {
        public final String value;
        public StringConstant(int pc, String value, int destination, Opcode opcode, DexIMethod method)
        {
            super(pc, destination, opcode, method);
            this.value = value;
        }
    }

    public static class ClassConstant extends Constant
    {
        public final TypeReference value;

        public ClassConstant(int pc, TypeReference value, int destination, Opcode opcode, DexIMethod method)
        {
            super(pc, destination, opcode, method);
            this.value = value;
        }
    }

    @Override
    public void visit(Visitor visitor) {
        visitor.visitConstant(this);
    }

}

==> wala_1.5.2.orig.tar.xz: WALA-R_1.5.2/com.ibm.wala.dalvik/src/com/ibm/wala/dalvik/dex/instructions/Constant.java <==
/*
 * This program and the accompanying materials
 * are made available under the terms of the Eclipse Public License v1.0
 * which accompanies this distribution, and is available at
 * http://www.eclipse.org/legal/epl-v10.html.
 * 
 * This file is a derivative of code released under the terms listed below.  
 *
 */
/*
 *
 * Copyright (c) 2009-2012,
 *
 *  Adam Fuchs          <afuchs@cs.umd.edu>
 *  Avik Chaudhuri      <avik@cs.umd.edu>
 *  Steve Suh           <suhsteve@gmail.com>
 *
 * All rights reserved.
 *
 * Redistribution and use in source and binary forms, with or without
 * modification, are permitted provided that the following conditions are met:
 *
 * 1. Redistributions of source code must retain the above copyright notice,
 * this list of conditions and the following disclaimer.
 *
 * 2. Redistributions in binary form must reproduce the above copyright notice,
 * this list of conditions and the following disclaimer in the documentation
 * and/or other materials provided with the distribution.
 *
 * 3. The names of the contributors may not be used to endorse or promote
 * products derived from this software without specific prior written
 * permission.
 *
 * THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS "AS IS"
 * AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE
 * IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE
 * ARE DISCLAIMED. IN NO EVENT SHALL THE COPYRIGHT OWNER OR CONTRIBUTORS BE
 * LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY, OR
 * CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF
 * SUBSTITUTE GOODS OR SERVICES; LOSS OF USE, DATA, OR PROFITS; OR BUSINESS
 * INTERRUPTION) HOWEVER CAUSED AND ON ANY THEORY OF LIABILITY, WHETHER IN
 * CONTRACT, STRICT LIABILITY, OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE)
 * ARISING IN ANY WAY OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE
 * POSSIBILITY OF SUCH DAMAGE.
 *
 *
 */

package com.ibm.wala.dalvik.dex.instructions;

import org.jf.dexlib2.Opcode;

import com.ibm.wala.dalvik.classLoader.DexIMethod;
import com.ibm.wala.types.TypeReference;

public abstract class Constant extends Instruction {

    public final int destination;

    public static class LongConstant extends Constant {
        public final long value;
        public LongConstant(int pc, long value, int destination, Opcode opcode, DexIMethod method)
        {
            super(pc, destination, opcode, method);
            this.value = value;
        }

    }

    protected Constant(int pc, int destination, Opcode opcode, DexIMethod method) {
        super(pc, opcode, method);
        this.destination = destination;
    }

    public static class IntConstant extends Constant
    {
        public final int value;
        public IntConstant(int pc, int value, int destination, Opcode opcode, DexIMethod method)
        {
            super(pc, destination, opcode, method);
            this.value = value;
        }
    }

    public static class StringConstant extends Constant
    {
        public final String value;
        public StringConstant(int pc, String value, int destination, Opcode opcode, DexIMethod method)
        {
            super(pc, destination, opcode, method);
            this.value = value;
        }
    }

    public static class ClassConstant extends Constant
    {
        public final TypeReference value;

        public ClassConstant(int pc, TypeReference value, int destination, Opcode opcode, DexIMethod method)
        {
            super(pc, destination, opcode, method);
            this.value = value;
        }
    }

    @Override
    public void visit(Visitor visitor) {
        visitor.visitConstant(this);
    }

}
